pub enum IotaError {
Show 96 variants
UserInput {
error: UserInputError,
},
TooManyTransactionsPendingExecution {
queue_len: usize,
threshold: usize,
},
TooManyTransactionsPendingConsensus,
TooManyTransactionsPendingOnObject {
object_id: ObjectId,
queue_len: usize,
threshold: usize,
},
TooOldTransactionPendingOnObject {
object_id: ObjectId,
txn_age_sec: u64,
threshold: u64,
},
InvalidTxKindInSoftBundle,
InvalidSignature {
error: String,
},
SignerSignatureAbsent {
expected: String,
actual: Vec<String>,
},
SignerSignatureNumberMismatch {
expected: usize,
actual: usize,
},
IncorrectSigner {
error: String,
},
UnknownSigner {
signer: Option<String>,
index: Option<u32>,
committee: Box<Committee>,
},
StakeAggregatorRepeatedSigner {
signer: AuthorityName,
conflicting_sig: bool,
},
PotentiallyTemporarilyInvalidSignature {
error: String,
},
WrongEpoch {
expected_epoch: EpochId,
actual_epoch: EpochId,
},
CertificateRequiresQuorum,
ErrorWhileProcessingCertificate {
err: String,
},
QuorumFailedToGetEffectsQuorumWhenProcessingTransaction {
effects_map: BTreeMap<TransactionEffectsDigest, (Vec<AuthorityName>, StakeUnit)>,
},
FailedToVerifyTxCertWithExecutedEffects {
validator_name: AuthorityName,
error: String,
},
TxAlreadyFinalizedWithDifferentUserSigs,
InvalidAuthenticator,
InvalidAddress,
InvalidTransactionDigest,
InvalidMoveAuthenticatorDigest,
InvalidDigestLength {
expected: usize,
actual: usize,
},
InvalidDkgMessageSize,
UnexpectedMessage,
MoveAuthenticatorExecutionFailure {
error: String,
},
ModuleVerificationFailure {
error: String,
},
ModuleDeserializationFailure {
error: String,
},
ModulePublishFailure {
error: String,
},
ModuleBuildFailure {
error: String,
},
FunctionNotFound {
error: String,
},
ModuleNotFound {
module_name: String,
},
Type {
error: String,
},
CircularObjectOwnership,
ObjectLockAlreadyInitialized {
refs: Vec<ObjectReference>,
},
ObjectLockConflict {
obj_ref: ObjectReference,
pending_transaction: TransactionDigest,
},
ObjectLockedAtFutureEpoch {
obj_refs: Vec<ObjectReference>,
locked_epoch: EpochId,
new_epoch: EpochId,
locked_by_tx: TransactionDigest,
},
RecentlyResubmitted {
digest: TransactionDigest,
},
TransactionNotFound {
digest: TransactionDigest,
},
TransactionsNotFound {
digests: Vec<TransactionDigest>,
},
TransactionEventsNotFound {
digest: TransactionDigest,
},
TransactionAlreadyExecuted {
digest: TransactionDigest,
},
BadObjectType {
error: String,
},
FailObjectLayout {
st: String,
},
ExecutionInvariantViolation,
ByzantineAuthoritySuspicion {
authority: AuthorityName,
reason: String,
},
InvalidChildObjectAccess {
object: ObjectId,
given_parent: ObjectId,
actual_owner: Owner,
},
GenericAuthority {
error: String,
},
FailedToDispatchSubscription {
error: String,
},
OwnerFailedToSerialize {
error: String,
},
ExtraFieldFailedToDeserialize {
error: String,
},
TransactionOrchestratorLocalExecution {
error: String,
},
TransactionSerialization {
error: String,
},
ObjectSerialization {
error: String,
},
ObjectDeserialization {
error: String,
},
RuntimeModuleMetadataDeserialization {
error: String,
},
NoEventStore,
TooManyIncorrectAuthorities {
errors: Vec<(AuthorityName, IotaError)>,
action: String,
},
FullNodeInvalidTxRangeQuery {
error: String,
},
FailedToSubmitToConsensus(String),
ConsensusConnectionBroken(String),
HandleConsensusTransactionFailure(String),
SignatureKeyGen(String),
KeyConversion(String),
InvalidPrivateKey,
FullNodeCantHandleCertificate,
FullNodeCantHandleValidatorV2,
FullNodeCantHandleAuthorityCapabilities,
ValidatorHaltedAtEpochEnd,
EpochEnded(EpochId),
AdvanceEpoch {
error: String,
},
TransactionExpired,
Rpc(String, String),
InvalidRpcMethod,
UnsupportedFeature {
error: String,
},
QuorumDriverCommunication {
error: String,
},
Timeout,
Execution(String),
InvalidCommittee(String),
MissingCommitteeAtEpoch(EpochId),
IndexStoreNotAvailable,
DynamicFieldRead(String),
IotaSystemStateRead(String),
UnexpectedVersion(String),
WrongMessageVersion {
error: String,
},
Unknown(String),
FileIO(String),
JWKRetrieval,
Storage(String),
ValidatorOverloadedRetryAfter {
retry_after_secs: u64,
},
TooManyRequests,
NoCertificateProvided,
InvalidAdminRequest(String),
TransactionEffectsNotFound {
digest: TransactionDigest,
},
DynamicFieldNotExists {
parent_id: ObjectId,
id: ObjectId,
key: String,
},
}Expand description
Custom error type for Iota.
WARNING: This enum is sent between nodes, and the code of a variant is its
declaration index. Add new variants only at the very end of the enum, then
re-run the unit tests and commit the updated variant-order snapshot from
tests/staged/ together with the change.
The same rules apply to enums embedded in variant fields, such as
UserInputError.
Variants
UserInput
Fields
error: UserInputErrorTooManyTransactionsPendingExecution
TooManyTransactionsPendingConsensus
TooManyTransactionsPendingOnObject
TooOldTransactionPendingOnObject
InvalidTxKindInSoftBundle
InvalidSignature
SignerSignatureAbsent
SignerSignatureNumberMismatch
IncorrectSigner
UnknownSigner
StakeAggregatorRepeatedSigner
PotentiallyTemporarilyInvalidSignature
WrongEpoch
CertificateRequiresQuorum
ErrorWhileProcessingCertificate
QuorumFailedToGetEffectsQuorumWhenProcessingTransaction
Fields
effects_map: BTreeMap<TransactionEffectsDigest, (Vec<AuthorityName>, StakeUnit)>FailedToVerifyTxCertWithExecutedEffects
TxAlreadyFinalizedWithDifferentUserSigs
InvalidAuthenticator
InvalidAddress
InvalidTransactionDigest
InvalidMoveAuthenticatorDigest
InvalidDigestLength
InvalidDkgMessageSize
UnexpectedMessage
MoveAuthenticatorExecutionFailure
ModuleVerificationFailure
ModuleDeserializationFailure
ModulePublishFailure
ModuleBuildFailure
FunctionNotFound
ModuleNotFound
Type
CircularObjectOwnership
ObjectLockAlreadyInitialized
ObjectLockConflict
ObjectLockedAtFutureEpoch
Fields
locked_by_tx: TransactionDigestRecentlyResubmitted
Fields
digest: TransactionDigestTransactionNotFound
Fields
digest: TransactionDigestTransactionsNotFound
TransactionEventsNotFound
Fields
digest: TransactionDigestTransactionAlreadyExecuted
Fields
digest: TransactionDigestBadObjectType
FailObjectLayout
ExecutionInvariantViolation
ByzantineAuthoritySuspicion
InvalidChildObjectAccess
GenericAuthority
FailedToDispatchSubscription
OwnerFailedToSerialize
ExtraFieldFailedToDeserialize
TransactionOrchestratorLocalExecution
TransactionSerialization
ObjectSerialization
ObjectDeserialization
RuntimeModuleMetadataDeserialization
NoEventStore
TooManyIncorrectAuthorities
FullNodeInvalidTxRangeQuery
FailedToSubmitToConsensus(String)
ConsensusConnectionBroken(String)
HandleConsensusTransactionFailure(String)
SignatureKeyGen(String)
KeyConversion(String)
InvalidPrivateKey
FullNodeCantHandleCertificate
FullNodeCantHandleValidatorV2
FullNodeCantHandleAuthorityCapabilities
ValidatorHaltedAtEpochEnd
EpochEnded(EpochId)
AdvanceEpoch
TransactionExpired
Rpc(String, String)
InvalidRpcMethod
UnsupportedFeature
QuorumDriverCommunication
Timeout
Execution(String)
InvalidCommittee(String)
MissingCommitteeAtEpoch(EpochId)
IndexStoreNotAvailable
DynamicFieldRead(String)
IotaSystemStateRead(String)
UnexpectedVersion(String)
WrongMessageVersion
Unknown(String)
FileIO(String)
JWKRetrieval
Storage(String)
ValidatorOverloadedRetryAfter
TooManyRequests
NoCertificateProvided
InvalidAdminRequest(String)
TransactionEffectsNotFound
Fields
digest: TransactionDigestDynamicFieldNotExists
Implementations
Sourceimpl IotaError
impl IotaError
pub fn individual_error_indicates_epoch_change(&self) -> bool
Sourcepub fn is_retryable(&self) -> (bool, bool)
pub fn is_retryable(&self) -> (bool, bool)
Returns if the error is retryable and if the error’s retryability is explicitly categorized. There should be only a handful of retryable errors. For now we list common non-retryable error below to help us find more retryable errors in logs.
pub fn is_object_or_package_not_found(&self) -> bool
pub fn is_overload(&self) -> bool
pub fn is_retryable_overload(&self) -> bool
Sourcepub fn is_storage_or_epoch_error(&self) -> bool
pub fn is_storage_or_epoch_error(&self) -> bool
Returns true for errors caused by storage or epoch-lifecycle
failures (RocksDB, epoch store closed) rather than semantic transaction
problems. Used by post-consensus validation to distinguish fatal errors
(halt the commit) from per-transaction drops.
pub fn retry_after_secs(&self) -> u64
Sourceimpl IotaError
impl IotaError
Sourcepub fn categorize(&self) -> ErrorCategory
pub fn categorize(&self) -> ErrorCategory
Categorizes this error into an ErrorCategory.