ExecutionError

Struct ExecutionError 

pub struct ExecutionError { /* private fields */ }

Implementations

Source

impl ExecutionError

pub fn new( kind: ExecutionErrorKind, source: Option<Box<dyn Error + Send + Sync + 'static>>, ) -> Self

pub fn new_with_source<E: Into<Box<dyn Error + Send + Sync + 'static>>>( kind: ExecutionErrorKind, source: E, ) -> Self

pub fn invariant_violation<E: Into<Box<dyn Error + Send + Sync + 'static>>>( source: E, ) -> Self

pub fn with_command_index(self, command: u64) -> Self

pub fn into_move_authentication_error(self) -> Self

Rewrap this error, produced while executing a Move authenticator, as a [ExecutionFailureStatus::MoveAuthenticationError]. The command index is dropped: it referred to a command of the authenticator’s own programmable transaction and is meaningless in the transaction’s effects, where it would otherwise collide with the first command of the programmable transaction.

pub fn from_kind(kind: ExecutionErrorKind) -> Self

pub fn kind(&self) -> &ExecutionErrorKind

pub fn command(&self) -> Option<u64>

pub fn source(&self) -> &Option<Box<dyn Error + Send + Sync + 'static>>

pub fn to_execution_status(&self) -> (ExecutionFailureStatus, Option<u64>)